@@ -23,7 +23,6 @@ from pyubx2.ubxhelpers import (
     itow2utc,
     gnss2str,
     key_from_val,
-    get_bits,
 )
 
 
@@ -73,6 +72,7 @@ class UBXMessage:
             self._ubxID = ubxID
 
         self._do_attributes(**kwargs)
+
         self._immutable = True  # once initialised, object is immutable
 
     def _do_attributes(self, **kwargs):
@@ -95,7 +95,7 @@ class UBXMessage:
             else:
                 self._payload = kwargs.get("payload", b"")
                 pdict = self._get_dict(**kwargs)  # get appropriate payload dict
-                for key in pdict.keys():  # process each attribute in dict
+                for key in pdict:  # process each attribute in dict
                     (offset, index) = self._set_attribute(
                         offset, pdict, key, index, **kwargs
                     )
@@ -136,7 +136,7 @@ class UBXMessage:
         if isinstance(
             att, tuple
         ):  # repeating group of attributes or subdefined bitfield
-            numr, attd = att
+            numr, _ = att
             if numr in (ubt.X1, ubt.X2, ubt.X4, ubt.X6, ubt.X8):  # bitfield
                 if self._parsebf:  # if we're parsing bitfields
                     (offset, index) = self._set_attribute_bitfield(
@@ -148,7 +148,7 @@ class UBXMessage:
                     )
             else:  # repeating group of attributes
                 (offset, index) = self._set_attribute_group(
-                    att, offset, index, **kwargs
+                    att, offset, key, index, **kwargs
                 )
         else:  # single attribute
             offset = self._set_attribute_single(att, offset, key, index, **kwargs)
@@ -156,13 +156,14 @@ class UBXMessage:
         return (offset, index)
 
     def _set_attribute_group(
-        self, att: tuple, offset: int, index: list, **kwargs
+        self, att: tuple, offset: int, key: str, index: list, **kwargs
     ) -> tuple:
         """
         Process (nested) group of attributes.
 
         :param tuple att: attribute group - tuple of (num repeats, attribute dict)
         :param int offset: payload offset in bytes
+        :param str key: group keyword
         :param list index: repeating group index array
         :param kwargs: optional payload key/value pairs
         :return: (offset, index[])
@@ -179,7 +180,7 @@ class UBXMessage:
             and self._ubxID == b"\x8b"
             and self._mode == ubt.GET
         ):
-            self._set_cfgval_attributes(offset, **kwargs)
+            self._set_attribute_cfgval(offset, **kwargs)
         else:
             # derive or retrieve number of items in group
             if isinstance(numr, int):  # fixed number of repeats
@@ -192,7 +193,7 @@ class UBXMessage:
             # incrementing the payload offset and index as we go
             for i in range(rng):
                 index[-1] = i + 1
-                for key1 in attd.keys():
+                for key1 in attd:
                     (offset, index) = self._set_attribute(
                         offset, attd, key1, index, **kwargs
                     )
@@ -222,7 +223,7 @@ class UBXMessage:
         keyr = key
         for i in index:  # one index for each nested level
             if i > 0:
-                keyr = keyr + "_{0:0=2d}".format(i)
+                keyr += f"_{i:02d}"
 
         # determine attribute size (bytes)
         if att == ubt.CH:  # variable length string
@@ -318,16 +319,13 @@ class UBXMessage:
         keyr = key
         for i in index:  # one index for each nested level
             if i > 0:
-                keyr = keyr + "_{0:0=2d}".format(i)
+                keyr += f"_{i:02d}"
 
         atts = attsiz(keyt)  # determine flag size in bits
 
         if "payload" in kwargs:
             mask = pow(2, atts) - 1
             val = (bitfield >> bfoffset) & mask
-            # print(
-            #     f"DEBUG key = {keyr}, bitfield = {bitfield:08b}, offset bitfield = {bitfield>>bfoffset:08b}, mask = {mask}, val={val}"
-            # )
         else:
             val = kwargs.get(keyr, 0)
             bitfield = bitfield | (val << bfoffset)
@@ -337,7 +335,7 @@ class UBXMessage:
         bfoffset += atts
         return (bitfield, bfoffset)
 
-    def _set_cfgval_attributes(self, offset: int, **kwargs):
+    def _set_attribute_cfgval(self, offset: int, **kwargs):
         """
         Parse CFG-VALGET payload to set of configuration
         key value pairs.
