@@ -32,47 +32,35 @@ class UBXReader:
     UBXReader class.
     """
 
-    def __init__(self, stream, *args, **kwargs):
+    def __init__(self, stream, **kwargs):
         """Constructor.
 
         :param stream stream: input data stream
-        :param bool ubxonly (kwarg): check for non-UBX data (False (ignore - default), True (reject))
-        :param int validate (kwarg): validate checksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
-        :param int msgmode (kwarg): message mode (0=GET (default), 1=SET, 2=POLL)
-        :param bool parsebitfield (kwarg): parse bitfields True/false
+        :param bool ubxonly: (kwarg) check non-UBX data (False (ignore - default), True (reject))
+        :param int validate: (kwarg) validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
+        :param int msgmode: (kwarg) message mode (0=GET (default), 1=SET, 2=POLL)
+        :param bool parsebitfield: (kwarg) parse bitfields True (default)/False
         :raises: UBXStreamError (if mode is invalid)
 
         """
 
-        ubx_only = kwargs.get("ubxonly", False)
-        validate = kwargs.get("validate", VALCKSUM)
-        parsebf = kwargs.get("parsebitfield", True)
-        msgmode = kwargs.get("msgmode", 0)
-
-        # accept args for backwards compatibility if no kwargs
-        if len(kwargs) == 0:
-            if len(args) > 0:
-                ubx_only = args[0]
-            if len(args) > 1:
-                msgmode = args[1]
-
-        if msgmode not in (0, 1, 2):
-            raise ube.UBXStreamError(
-                f"Invalid stream mode {msgmode} - must be 0, 1 or 2"
-            )
-
         self._stream = stream
-        self._ubx_only = ubx_only
-        self._validate = validate
-        self._mode = msgmode
-        self._parsebf = parsebf
+        self._ubx_only = kwargs.get("ubxonly", False)
+        self._validate = kwargs.get("validate", VALCKSUM)
+        self._parsebf = kwargs.get("parsebitfield", True)
+        self._msgmode = kwargs.get("msgmode", 0)
+
+        if self._msgmode not in (0, 1, 2):
+            raise ube.UBXStreamError(
+                f"Invalid stream mode {self._msgmode} - must be 0, 1 or 2"
+            )
 
     def __iter__(self):
         """Iterator."""
 
         return self
 
-    def __next__(self) -> (bytes, UBXMessage):
+    def __next__(self) -> tuple:
         """
         Return next item in iteration.
 
@@ -108,11 +96,11 @@ class UBXReader:
             is_nmea = False
             if len(byte1) < 1:  # EOF
                 break
-            if byte1 == b"\xb5":
+            if byte1 == ubt.UBX_HDR[0:1]:
                 byte2 = self._stream.read(1)
                 if len(byte2) < 1:  # EOF
                     break
-                if byte2 == b"\x62":
+                if byte2 == ubt.UBX_HDR[1:2]:
                     is_ubx = True
             if is_ubx:  # it's a UBX message
                 byten = self._stream.read(4)
@@ -131,7 +119,7 @@ class UBXReader:
                 parsed_data = self.parse(
                     raw_data,
                     validate=self._validate,
-                    msgmode=self._mode,
+                    msgmode=self._msgmode,
                     parsebitfield=self._parsebf,
                 )
                 reading = False
@@ -149,7 +137,7 @@ class UBXReader:
         return (raw_data, parsed_data)
 
     @staticmethod
-    def parse(message: bytes, *args, **kwargs) -> object:
+    def parse(message: bytes, **kwargs) -> object:
         """
         Parse UBX byte stream to UBXMessage object.
 
@@ -157,8 +145,9 @@ class UBXReader:
         (the UBXMessage constructor can calculate and assign its own values anyway).
 
         :param bytes message: binary message to parse
-        :param int validate (kwarg): validate checksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
-        :param int msgmode (kwarg): message mode (0=GET (default), 1=SET, 2=POLL)
+        :param int validate: (kwarg) validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
+        :param int msgmode: (kwarg) message mode (0=GET (default), 1=SET, 2=POLL)
+        :param bool parsebitfield: (kwarg) parse bitfields True (default)/False
         :return: UBXMessage object
         :rtype: UBXMessage
         :raises: UBXParseError (if data stream contains invalid data or unknown message type)
@@ -169,13 +158,6 @@ class UBXReader:
         validate = kwargs.get("validate", VALCKSUM)
         parsebf = kwargs.get("parsebitfield", True)
 
-        # accept args for backwards compatibility if no kwargs
-        if len(kwargs) == 0:
-            if len(args) > 0:
-                validate = args[0]
-            if len(args) > 1:
-                msgmode = args[1]
-
         if msgmode not in (0, 1, 2):
             raise ube.UBXParseError(
                 f"Invalid message mode {msgmode} - must be 0, 1 or 2"
@@ -217,7 +199,11 @@ class UBXReader:
             if payload is None:
                 return UBXMessage(clsid, msgid, msgmode)
             return UBXMessage(
-                clsid, msgid, msgmode, payload=payload, parsebitfield=parsebf
+                clsid,
+                msgid,
+                msgmode,
+                payload=payload,
+                parsebitfield=parsebf,
             )
         except KeyError as err:
             modestr = ["GET", "SET", "POLL"][msgmode]
