@@ -1,4 +1,3 @@
-# pylint: disable=line-too-long
 """
 UBX Protocol core globals and constants
 
@@ -9,7 +8,7 @@ Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
 :author: semuadmin
 """
 
-UBX_HDR = b"\xB5\x62"
+UBX_HDR = b"\xb5\x62"
 INPUT = 1
 OUTPUT = 0
 GET = 0
@@ -54,6 +53,7 @@ U7 = "U007"  # Unsigned Int 7 bytes
 U8 = "U008"  # Unsigned Int 8 bytes
 U9 = "U009"  # Unsigned Int 9 bytes
 U12 = "U012"  # Unsigned Int 12 bytes
+U20 = "U020"  # Unsigned Int 20 bytes
 U22 = "U022"  # Unsigned Int 22 bytes
 U40 = "U040"  # Unsigned Int 40 bytes
 U64 = "U064"  # Unsigned Int 64 bytes
@@ -94,6 +94,7 @@ VALID_TYPES = (
     U8,
     U9,
     U12,
+    U20,
     U22,
     U40,
     U64,
@@ -108,6 +109,7 @@ VALID_TYPES = (
 # ***********************************************
 # THESE ARE THE UBX PROTOCOL CORE MESSAGE CLASSES
 # ***********************************************
+# pylint: disable=line-too-long
 UBX_CLASSES = {
     b"\x01": "NAV",  # Navigation Results: Position, Speed, Time, Acc, Heading, DOP, SVs used
     b"\x02": "RXM",  # Receiver Manager Messages: Satellite Status, RTC Status
