@@ -4,21 +4,6 @@ UBX Protocol Output payload definitions
 THESE ARE THE PAYLOAD DEFINITIONS FOR _GET_ MESSAGES _FROM_ THE RECEIVER
 (e.g. Periodic Navigation Data; Poll Responses; Info messages)
 
-NB: Attribute names must be unique within each message class/id
-
-NB: Repeating or bitfield groups must be defined as a tuple thus
-    'group': ('numr', {dict})
-    where
-    - 'numr' is either:
-       a) an integer representing a fixed number of repeats e.g 32
-       b) a string representing the name of a preceding attribute
-          containing the number of repeats e.g. 'numCh'
-       c) an 'X' attribute type ('X1', 'X2', 'X4', etc) representing a group of individual bit flags
-       d) 'None' for a 'variable by size' repeating group
-          (only one such group is permitted per message type)
-    - {dict} is the nested dictionary containing the repeating
-      attributes
-
 Created on 27 Sep 2020
 
 Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
@@ -50,6 +35,7 @@ from pyubx2.ubxtypes_core import (
     U8,
     U9,
     U12,
+    U20,
     U22,
     U64,
     X1,
@@ -58,6 +44,7 @@ from pyubx2.ubxtypes_core import (
     X24,
 )
 
+
 UBX_PAYLOADS_GET = {
     "ACK-ACK": {"clsID": U1, "msgID": U1},
     "ACK-NAK": {"clsID": U1, "msgID": U1},
@@ -191,6 +178,7 @@ UBX_PAYLOADS_GET = {
                 "devBBR": U1,
                 "devFlash": U1,
                 "devEEPROM": U1,
+                "reserved1": U1,
                 "devSpiFlash": U1,
             },
         ),
@@ -664,6 +652,7 @@ UBX_PAYLOADS_GET = {
         "flags": (
             X4,
             {
+                "reserved3": U1,
                 "optTarget": U3,
                 "extintSel": U1,
                 "extintWake": U1,
@@ -673,7 +662,7 @@ UBX_PAYLOADS_GET = {
                 "waitTimeFix": U1,
                 "updateRTC": U1,
                 "updateEPH": U1,
-                "reserved12": U3,
+                "reserved4": U3,
                 "doNotEnterOff": U1,
                 "operationMode": U2,
             },
@@ -683,14 +672,8 @@ UBX_PAYLOADS_GET = {
         "gridOffset": U4,
         "onTime": U2,
         "minAcqTime": U2,
-        "reserved4": U2,
-        "reserved5": U2,
-        "reserved6": U4,
-        "reserved7": U4,
-        "reserved8": U1,
-        "reserved9": U1,
-        "reserved10": U2,
-        "reserved11": U4,
+        "reserved2": U20,
+        "extintInactivityMs": U4,
     },
     "CFG-PMS": {
         "version": U1,
@@ -741,7 +724,13 @@ UBX_PAYLOADS_GET = {
                 "outRTCM3": U1,
             },
         ),
-        "reserved4": U2,
+        "flags": (
+            X2,
+            {
+                "reserved10": U1,
+                "extendedTxTimeout": U1,
+            },
+        ),
         "reserved5": U2,
     },
     "CFG-PWR": {"version": U1, "reserved1": U3, "state": U4},
@@ -2300,7 +2289,15 @@ UBX_PAYLOADS_GET = {
         "fTOW": I4,
         "week": I2,
         "gpsFix": U1,
-        "flags": X1,  # TODO
+        "flags": (
+            X1,
+            {
+                "gpsfixOK": U1,
+                "diffSoln": U1,
+                "wknSet": U1,
+                "towSet": U1,
+            },
+        ),
         "ecefX": I4,
         "ecefY": I4,
         "ecefZ": I4,
@@ -2741,7 +2738,7 @@ UBX_PAYLOADS_GET = {
         "chn": U1,
         "version": U1,
         "reserved1": U1,
-        "group": ("numWords", {"dwrd": U4}),  # repeating group * numWords
+        "navdata": ("numWords", {"dwrd": U4}),  # repeating group * numWords
     },
     "RXM-SVSI": {
         "iTOW": U4,
