@@ -1,24 +1,9 @@
-# pylint: disable=unused-import
 """
 UBX Protocol Input payload definitions
 
 THESE ARE THE PAYLOAD DEFINITIONS FOR _SET_ MESSAGES _TO_ THE RECEIVER
 (e.g. configuration and calibration commands; AssistNow payloads)
 
-NB: Attribute names must be unique within each message class/id
-
-NB: Repeating groups must be defined as a tuple thus:
-    'group': ('numr', {dict})
-    where
-    - 'numr' is either:
-       a) an integer representing a fixed number of repeats e.g 32
-       b) a string representing the name of a preceding attribute
-          containing the number of repeats e.g. 'numCh'
-       c) 'None' for a 'variable by size' repeating group
-          (only one such group is permitted per message type)
-    - {dict} is the nested dictionary containing the repeating
-      attributes
-
 Created on 27 Sep 2020
 
 Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
@@ -46,6 +31,7 @@ from pyubx2.ubxtypes_core import (
     U8,
     U9,
     U12,
+    U20,
     U22,
     U40,
     U64,
@@ -184,6 +170,7 @@ UBX_PAYLOADS_SET = {
                 "devBBR": U1,
                 "devFlash": U1,
                 "devEEPROM": U1,
+                "reserved1": U1,
                 "devSpiFlash": U1,
             },
         ),
@@ -657,6 +644,7 @@ UBX_PAYLOADS_SET = {
         "flags": (
             X4,
             {
+                "reserved3": U1,
                 "optTarget": U3,
                 "extintSel": U1,
                 "extintWake": U1,
@@ -666,7 +654,7 @@ UBX_PAYLOADS_SET = {
                 "waitTimeFix": U1,
                 "updateRTC": U1,
                 "updateEPH": U1,
-                "reserved12": U3,
+                "reserved4": U3,
                 "doNotEnterOff": U1,
                 "operationMode": U2,
             },
@@ -676,14 +664,8 @@ UBX_PAYLOADS_SET = {
         "gridOffset": U4,
         "onTime": U2,
         "minAcqTime": U2,
-        "reserved4": U2,
-        "reserved5": U2,
-        "reserved6": U4,
-        "reserved7": U4,
-        "reserved8": U1,
-        "reserved9": U1,
-        "reserved10": U2,
-        "reserved11": U4,
+        "reserved2": U20,
+        "extintInactivityMs": U4,
     },
     "CFG-PMS": {
         "version": U1,
@@ -734,7 +716,13 @@ UBX_PAYLOADS_SET = {
                 "outRTCM3": U1,
             },
         ),
-        "reserved4": U2,
+        "flags": (
+            X2,
+            {
+                "reserved10": U1,
+                "extendedTxTimeout": U1,
+            },
+        ),
         "reserved5": U2,
     },
     "CFG-PWR": {"version": U1, "reserved1": U3, "state": U4},
